This function returns the subset of x object as defined by y extent object.
See crop and extent for more details.
The difference between crop and cropsebkc is the ability for the
latter to reproject y object with x object projection.
Examples
if (FALSE) { # \dontrun{
folder=system.file("extdata","stack",package="sebkc")
stack=sebkcstack(folder=folder)
data=cropsebkc(stack$data,stack$data)
} # }